@@ -1,12 +1,11 @@
 use rust_decimal::prelude::ToPrimitive;
 use rust_decimal::Decimal;
-use rusty_v8 as v8;
-use rusty_v8::HandleScope;
 use std::collections::HashSet;
 use std::fs::DirEntry;
 use std::path::Path;
 use std::sync::Mutex;
 use std::{fs, io};
+use v8::HandleScope;
 use v_common::onto::datatype::Lang;
 use v_common::onto::individual::Individual;
 use v_common::onto::onto::Onto;
@@ -173,7 +172,10 @@ fn add_v8_value_obj_to_individual<'a>(
                 }
             }
             "Integer" => {
-                if vdata.is_number() {
+                if vdata.is_big_int() {
+                    let (i64val, _is_truncate) = vdata.to_big_int(scope).unwrap().i64_value();
+                    res.add_integer(&predicate, i64val);
+                } else if vdata.is_number() {
                     res.add_integer(&predicate, vdata.integer_value(scope).unwrap());
                 } else if vdata.is_string() {
                     if let Some(v) = vdata.to_string(scope) {
@@ -296,11 +298,11 @@ pub fn individual2v8obj<'a>(scope: &mut HandleScope<'a>, src: &mut Individual) -
                     set_key_str_value(scope, &mut v8_value, "type", "Decimal");
                 }
                 Value::Int(i) => {
-                    if *i < i32::max as i64 {
-                        set_key_i32_value(scope, &mut v8_value, "data", *i as i32);
+                    let i_val = *i;
+                    if i_val < i32::MAX as i64 {
+                        set_key_i32_value(scope, &mut v8_value, "data", i_val as i32);
                     } else {
-                        set_key_i64_value(scope, &mut v8_value, "data", *i as i64);
-                        //                        error!("individual2v8obj: predicate{}, {} > i32.max", predicate, i);
+                        set_key_i64_value(scope, &mut v8_value, "data", i_val);
                     }
                     set_key_str_value(scope, &mut v8_value, "type", "Integer");
                 }
